function U=dft16(u,type,n0)
%DFT16 16 punkters DFT.
%
%    X = DFT16(x,typ) - x r tidsdiskret signal, typ r text.
%    X = DFT16(x,typ,n0) - x r tidsdiskret signal, typ r text, 
%                        n0 r reellt heltal.
%    
%    Beskrivning:
%    Fnstrar signalen x och berknar en 16 punkters DFT av den fnstrade 
%    signalen. Fnstertypen anges med textstrngen typ, vilken skall omges 
%    av apostrofer. Tillgngliga fnstertyper finns angivna i hjlptexten fr 
%    kretslabfunktionen window. 
%    Fnstringen brjar i n = n0. Om n0 utelmnas stts den till 0.
%    
%    Example:
%    x = sample('sin(2*pi*t)',5);
%    X = dft16(x,'hann',10);
%    
%    See also:
%    WINDOW, DFT8, DFT32, DFT64, DFT128
%    

global pm1 pm2 pm3 pm4 KlabL
if vtype(u)~=8, error('Input incorrect: not signal'); end
if nargin<3, n0=0; end
if n0<-KlabL/2 | n0+16>KlabL/2, error('Input incorrect'); end
u=window(u,type,16,n0);
U=[fft(u(KlabL/2+1+n0:KlabL/2+16+n0)) zeros(1,112) 16];
