function x=ilaptr(X)
%ILAPTR Invers laplacetransformering.
%
%    x = ILAPTR(X) - X r laplacetransform.
%    
%    Beskrivning:
%    Funktionen berknar invers laplacetransform fr laplacetransformer med
%    hgersidigt konvergensomrde och vars poler r enkla och finns i
%    vnster halvplan eller p jw-axeln.
%    
%    Example:
%    X = in([1],[1 1],'s');
%    x = ilaptr(X);
%    
%    Vanliga fel:
%    ilaptr anvnder en partialbrksuppdelning frn Matlabs bibliotek, och 
%    denna klarar inte multipelpoler. Se ven till att transformen inte har 
%    ngra poler i hger halvplan. Notera att signalen mste vara 
%    bandbegrnsad med ett frekvensinnehll under 3200 Hz.
%    
%    See also: 
%    IFOUTR, IZTR
%    

global pm1 pm2 pm3 pm4 KlabL FSMAX
if vtype(X)~=6, error('Input incorrect: not Laplace transform'); end
if any(real(X(2,4:3+X(2,2)))>0), error('Poles in rhpl'); end
b=bandwi(X);
if b==Inf, error('Infinite bandwidth'); end

% Test 2020-11-27 fr att f en inverstransform med hgre upplsning lngs
% tidsaxeln, dvs. som inte  lika hackig:
MAXPO = max(abs(imag(po(X))))/2/pi;  % Imaginrdelen/2pi av den pol som r lngst frn origo
if b<5*MAXPO
    b=min(5*MAXPO, FSMAX/2);   % Vlj en hgre bandbredd n den rtta/rimliga, s att inte inverstransformen blir s hackig nr den ritas.
end

t=(0:KlabL/2-1)/(2*b);
Xt=X(1,3)*poly(X(1,4:3+X(1,2)));
Xn=X(2,3)*poly(X(2,4:3+X(2,2)));
[r,p,k]=residue(Xt,Xn);
r=r';
p=p';
x=[zeros(1,KlabL) 1/(2*b)];
for i=1:length(r)
 x(1+KlabL/2:KlabL)=x(1+KlabL/2:KlabL)+r(i)*exp(p(i)*t);
end
if max(imag(x))>.01*max(real(x)),
 disp('Varning: Signalen r komplexvrd, realdelen anvnds.')
end
x=real(x);




 
